@@ -103,7 +103,7 @@ inline void debug_ast(AST_Node_Ptr node, std::string ind, Env* env)
     std::cerr << (selector->has_line_break() ? " [line-break]": " -");
     std::cerr << (selector->has_line_feed() ? " [line-feed]": " -");
     std::cerr << std::endl;
-    debug_ast(selector->schema(), "#{} ");
+    debug_ast(selector->schema(), ind + "#{} ");
 
     for (auto __i = (selector->elements()).begin(); __i != (selector->elements()).end(); ++__i) { const Complex_Selector_Obj& i = *(__i); debug_ast(i, ind + " ", env); }
 
